@@ -1,6 +1,5 @@
 package Net::CLI::Interact::ActionSet;
-{ $Net::CLI::Interact::ActionSet::VERSION = '2.400000' }
-
+$Net::CLI::Interact::ActionSet::VERSION = '2.400001';
 use Moo;
 use Sub::Quote;
 use MooX::Types::MooseLike::Base qw(InstanceOf ArrayRef CodeRef RegexpRef);
@@ -165,6 +164,8 @@ sub _marshall_responses {
 
 =pod
 
+=for Pod::Coverage BUILDARGS has_current_match has_default_continuation
+
 =head1 NAME
 
 Net::CLI::Interact::ActionSet - Conversation of Send and Match Actions
@@ -219,7 +220,7 @@ with the Action(s) according to how many are required.
 
 =head2 register_callback
 
-Allows the L<Transport|Net::CLI::Interact::Transport> to be registered
+Allows the Transport to be registered
 such that when the ActionSet is executed, commands are sent to the registered
 callback subroutine. May be called more than once, and on execution each of
 the callbacks will be run, in turn and in order.
