@@ -1,6 +1,5 @@
 package Net::CLI::Interact::Transport::Wrapper::Base;
-{ $Net::CLI::Interact::Transport::Wrapper::Base::VERSION = '2.400000' }
-
+$Net::CLI::Interact::Transport::Wrapper::Base::VERSION = '2.400001';
 use Moo;
 use Sub::Quote;
 use MooX::Types::MooseLike::Base qw(Int RegexpRef Str Object);
@@ -138,4 +137,24 @@ sub do_action {
     }
 }
 
+=pod
+
+=begin Pod::Coverage
+
+  DEMOLISH
+  buffer
+  connect_ready
+  disconnect
+  do_action
+  flush
+  has_app
+  init
+  irs_re
+  pump
+  put
+
+=end Pod::Coverage
+
+=cut
+
 1;
